summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_scheduler.py
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2017-06-12 22:43:07 +0200
committerHolger Levsen <holger@layer-acht.org>2017-06-16 16:28:34 +0200
commitfef02237f9f7aef649db16ba4162355f9a4deb2f (patch)
treef6d98b71946ee2544e15b7dfe6202268ffcd6a80 /bin/reproducible_scheduler.py
parentef7fe352e2bb940ac2495e1f303d5ca7c8385b38 (diff)
downloadjenkins.debian.net-fef02237f9f7aef649db16ba4162355f9a4deb2f.tar.xz
reproducible Debian: WIP for s#testing#stretch#g - see TODO4stretch_rename.txt for status
Signed-off-by: Holger Levsen <holger@layer-acht.org>
Diffstat (limited to 'bin/reproducible_scheduler.py')
-rwxr-xr-xbin/reproducible_scheduler.py42
1 files changed, 21 insertions, 21 deletions
diff --git a/bin/reproducible_scheduler.py b/bin/reproducible_scheduler.py
index 39ed8071..9138e174 100755
--- a/bin/reproducible_scheduler.py
+++ b/bin/reproducible_scheduler.py
@@ -71,110 +71,110 @@ MAXIMA = {'amd64': 1600, 'i386': 1500, 'arm64': 1500, 'armhf': 1000}
LIMITS = {
'untested': {
'amd64': {
- 'testing': {'*': 100},
+ 'stretch': {'*': 100},
'unstable': {'*': 100},
'experimental': {'*': 100},
},
'i386': {
- 'testing': {'*': 100},
+ 'stretch': {'*': 100},
'unstable': {'*': 100},
'experimental': {'*': 100},
},
'arm64': {
- 'testing': {'*': 100},
+ 'stretch': {'*': 100},
'unstable': {'*': 100},
'experimental': {'*': 100},
},
'armhf': {
- 'testing': {'*': 100},
+ 'stretch': {'*': 100},
'unstable': {'*': 100},
'experimental': {'*': 100},
},
},
'new': {
'amd64': {
- 'testing': {1: (100, 250), 2: (200, 200), '*': 100},
+ 'stretch': {1: (100, 250), 2: (200, 200), '*': 100},
'unstable': {1: (100, 250), 2: (200, 200), '*': 150},
'experimental': {1: (100, 250), 2: (200, 200), '*': 50},
},
'i386': {
- 'testing': {1: (100, 250), 2: (200, 200), '*': 100},
+ 'stretch': {1: (100, 250), 2: (200, 200), '*': 100},
'unstable': {1: (100, 250), 2: (200, 200), '*': 150},
'experimental': {1: (100, 250), 2: (200, 200), '*': 50},
},
'arm64': {
- 'testing': {1: (100, 250), 2: (200, 200), '*': 50},
+ 'stretch': {1: (100, 250), 2: (200, 200), '*': 50},
'unstable': {1: (100, 250), 2: (200, 200), '*': 75},
'experimental': {1: (100, 200), 2: (200, 200), '*': 25},
},
'armhf': {
- 'testing': {1: (100, 200), 2: (200, 200), '*': 50},
+ 'stretch': {1: (100, 200), 2: (200, 200), '*': 50},
'unstable': {1: (100, 200), 2: (200, 200), '*': 75},
'experimental': {1: (100, 200), 2: (200, 200), '*': 25},
},
},
'ftbfs': {
'amd64': {
- 'testing': {1: (700, 40), 2: (500, 20), '*': 5},
+ 'stretch': {1: (700, 40), 2: (500, 20), '*': 5},
'unstable': {1: (700, 40), 2: (500, 20), '*': 5},
'experimental': {1: (700, 40), 2: (500, 20), '*': 2},
},
'i386': {
- 'testing': {1: (700, 40), 2: (500, 20), '*': 5},
+ 'stretch': {1: (700, 40), 2: (500, 20), '*': 5},
'unstable': {1: (700, 40), 2: (500, 20), '*': 5},
'experimental': {1: (700, 40), 2: (500, 20), '*': 2},
},
'arm64': {
- 'testing': {1: (700, 40), 2: (500, 20), '*': 5},
+ 'stretch': {1: (700, 40), 2: (500, 20), '*': 5},
'unstable': {1: (700, 40), 2: (500, 20), '*': 5},
'experimental': {1: (700, 40), 2: (500, 20), '*': 2},
},
'armhf': {
- 'testing': {1: (575, 20), 2: (450, 10), '*': 5},
+ 'stretch': {1: (575, 20), 2: (450, 10), '*': 5},
'unstable': {1: (575, 20), 2: (450, 10), '*': 5},
'experimental': {1: (575, 20), 2: (450, 10), '*': 2},
}
},
'depwait': {
'amd64': {
- 'testing': {1: (700, 400), 2: (500, 200), '*': 50},
+ 'stretch': {1: (700, 400), 2: (500, 200), '*': 50},
'unstable': {1: (700, 400), 2: (500, 200), '*': 50},
'experimental': {1: (700, 400), 2: (500, 200), '*': 20},
},
'i386': {
- 'testing': {1: (700, 400), 2: (500, 200), '*': 50},
+ 'stretch': {1: (700, 400), 2: (500, 200), '*': 50},
'unstable': {1: (700, 400), 2: (500, 200), '*': 50},
'experimental': {1: (700, 400), 2: (500, 200), '*': 20},
},
'arm64': {
- 'testing': {1: (700, 400), 2: (500, 200), '*': 50},
+ 'stretch': {1: (700, 400), 2: (500, 200), '*': 50},
'unstable': {1: (700, 400), 2: (500, 200), '*': 50},
'experimental': {1: (700, 400), 2: (500, 200), '*': 20},
},
'armhf': {
- 'testing': {1: (575, 200), 2: (450, 100), '*': 50},
+ 'stretch': {1: (575, 200), 2: (450, 100), '*': 50},
'unstable': {1: (575, 200), 2: (450, 100), '*': 50},
'experimental': {1: (575, 200), 2: (450, 100), '*': 20},
}
},
'old': {
'amd64': {
- 'testing': {1: (700, 1000), 2: (1100, 850), '*': 0},
+ 'stretch': {1: (700, 1000), 2: (1100, 850), '*': 0},
'unstable': {1: (700, 1200), 2: (1100, 1050), '*': 0},
'experimental': {1: (700, 70), 2: (1100, 50), '*': 0},
},
'i386': {
- 'testing': {1: (700, 1000), 2: (1100, 850), '*': 0},
+ 'stretch': {1: (700, 1000), 2: (1100, 850), '*': 0},
'unstable': {1: (700, 1200), 2: (1100, 1050), '*': 0},
'experimental': {1: (700, 70), 2: (1100, 50), '*': 0},
},
'arm64': {
- 'testing': {1: (700, 1000), 2: (1100, 850), '*': 0},
+ 'stretch': {1: (700, 1000), 2: (1100, 850), '*': 0},
'unstable': {1: (700, 1200), 2: (1100, 1050), '*': 0},
'experimental': {1: (700, 70), 2: (1100, 50), '*': 0},
},
'armhf': {
- 'testing': {1: (600, 800), 2: (850, 500), '*': 0},
+ 'stretch': {1: (600, 800), 2: (850, 500), '*': 0},
'unstable': {1: (600, 1000), 2: (850, 700), '*': 0},
'experimental': {1: (600, 70), 2: (850, 50), '*': 0},
}
@@ -449,7 +449,7 @@ def query_new_versions(suite, arch, limit):
LIMIT {limit}""".format(suite=suite, arch=arch, limit=limit)
pkgs = query_db(query)
# the next line avoids constant rescheduling of packages:
# packages in our repository != sid or testing,
# so they will always be selected by the query above
# so we only accept them if there version is greater than the already tested one
packages = [(x[0], x[1]) for x in pkgs if version_compare(x[2], x[3]) > 0]
@@ -449,7 +449,7 @@ def query_new_versions(suite, arch, limit):
pkgs = query_db(query)
# the next line avoids constant rescheduling of packages:
- # packages in our repository != sid or testing,
+ # packages in our repository != sid or stretch,
# so they will always be selected by the query above
# so we only accept them if there version is greater than the already tested one